@@ -5,6 +5,7 @@
 
 from pathlib import Path
 import re
+import sys
 import textwrap
 
 import pytest
@@ -52,6 +53,10 @@ def test_parser_invalid():
     assert "could not determine a constructor for the tag" in errors[0]
 
 
+@pytest.mark.skipif(
+    sys.version_info < (3, 7),
+    reason="Error messages have literal 'OrderedDict' in them on Python 3.6",
+)
 def test_parser_schema_violation():
     """1507792"""
     all_metrics = parser.parse_objects(ROOT / "data" / "schema-violation.yaml")
@@ -159,18 +164,18 @@ def test_parser_schema_violation():
                 key_11:
                 description: Sample extra key
         ```
-        OrderedDict([('key_1', OrderedDict([('description', 'Sample extra
-        key')])), ('key_2', OrderedDict([('description', 'Sample extra
-        key')])), ('key_3', OrderedDict([('description', 'Sample extra
-        key')])), ('key_4', OrderedDict([('description', 'Sample extra
-        key')])), ('key_5', OrderedDict([('description', 'Sample extra
-        key')])), ('key_6', OrderedDict([('description', 'Sample extra
-        key')])), ('key_7', OrderedDict([('description', 'Sample extra
-        key')])), ('key_8', OrderedDict([('description', 'Sample extra
-        key')])), ('key_9', OrderedDict([('description', 'Sample extra
-        key')])), ('key_10', OrderedDict([('description', 'Sample extra
-        key')])), ('key_11', OrderedDict([('description', 'Sample extra
-        key')]))]) has too many properties
+        {'key_1': {'description': 'Sample extra key'},
+        'key_2': {'description': 'Sample extra key'},
+        'key_3': {'description': 'Sample extra key'},
+        'key_4': {'description': 'Sample extra key'},
+        'key_5': {'description': 'Sample extra key'},
+        'key_6': {'description': 'Sample extra key'},
+        'key_7': {'description': 'Sample extra key'},
+        'key_8': {'description': 'Sample extra key'},
+        'key_9': {'description': 'Sample extra key'},
+        'key_10': {'description': 'Sample extra key'},
+        'key_11': {'description': 'Sample extra key'}
+        } has too many properties
         Documentation for this node:
             The acceptable keys on the "extra" object sent with events. This is an
             object mapping the key to an object containing metadata about the key.
@@ -553,9 +558,22 @@ def test_send_in_pings_restrictions():
     all_metrics = parser.parse_objects(ROOT / "data" / "invalid-ping-names.yaml")
     errors = list(all_metrics)
     assert len(errors) == 1
+
     assert "'invalid_ping_name' does not match" in errors[0]
 
 
+def test_tags():
+    """Tests that tags can be specified."""
+    all_metrics = parser.parse_objects(ROOT / "data" / "metric-with-tags.yaml")
+    errors = list(all_metrics)
+
+    assert errors == []
+    assert len(all_metrics.value) == 1
+    assert all_metrics.value["telemetry"]["client_id"].metadata == {
+        "tags": ["banana", "apple"]
+    }
+
+
 def test_custom_expires():
     contents = [
         {
@@ -702,12 +720,15 @@ def test_text_invalid():
     errors = list(all_metrics)
     assert len(errors) == 3
 
+    def compare(expected, found):
+        return "".join(expected.split()) in "".join(found.split())
+
     for error in errors:
         if "sensitivity" in error:
-            assert "'technical' is not one of" in error
+            assert compare("'technical' is not one of", error)
 
         if "lifetime" in error:
-            assert "'user' is not one of" in error
+            assert compare("'user' is not one of", error)
 
         if "builtin_pings" in error:
-            assert "Built-in pings are not allowed" in error
+            assert compare("Built-in pings are not allowed", error)
